(()=>{var e={12744:()=>{var e=[],f=0;self.onmessage=function(s){if("channeldata"===s.data.msgtype)e[s.data.channelindex]=new Uint8Array(s.data.data),0===f&&(f=e[s.data.channelindex].length),self.fused||(self.fused=new Uint8Array(4*f),self.workerindex=s.data.workerindex);else if("fuse"===s.data.msgtype){!function(s,a){var r,t,d,l,n,o,u,i,x,h,c,v,g,m,p,w,b,y=s.length,M=4*f;for(m=0;m<M;m+=4)self.fused[m+0]=0,self.fused[m+1]=0,self.fused[m+2]=0,self.fused[m+3]=255;var k=0;if("m"===a){for(p=0;p<y;++p)if(g=(n=s[p]).chIndex,e[g]&&n.rgbColor)for(c=e[g],v=n.lut,w=0,b=0;w<f;w+=1,b+=4)o=v[4*(k=c[w])+0],u=v[4*k+1],i=v[4*k+2],h=(x=v[4*k+3])/255,r=self.fused[b+0],self.fused[b+0]=Math.max(r,o*h),t=self.fused[b+1],self.fused[b+1]=Math.max(t,u*h),d=self.fused[b+2],self.fused[b+2]=Math.max(d,i*h),l=self.fused[b+3],self.fused[b+3]=Math.max(l,x)}else if("a"===a){var C=0;for(p=0;p<y;++p)g=(n=s[p]).chIndex,e[g]&&n.rgbColor&&C++;for(p=0;p<y;++p)if(g=(n=s[p]).chIndex,e[g]&&n.rgbColor&&n.rgbColor)for(c=e[g],v=n.lut,w=0,b=0;w<f;w+=1,b+=4)o=v[4*(k=c[w])+0],u=v[4*k+1],i=v[4*k+2],h=(x=v[4*k+3])/255,self.fused[b+0]+=o*h/C,self.fused[b+1]+=u*h/C,self.fused[b+2]+=i*h/C,self.fused[b+3]+=x/C}}(s.data.combination,s.data.fuseMethod);var a={data:self.fused,workerindex:self.workerindex};postMessage(a,[a.data.buffer]),self.fused=new Uint8Array(4*f)}}}},f={};function s(a){var r=f[a];if(void 0!==r)return r.exports;var t=f[a]={exports:{}};return e[a](t,t.exports,s),t.exports}s.m=e,s.c=f,s.o=(e,f)=>Object.prototype.hasOwnProperty.call(e,f),(()=>{s.S={};var e={},f={};s.I=(a,r)=>{r||(r=[]);var t=f[a];if(t||(t=f[a]={}),!(r.indexOf(t)>=0)){if(r.push(t),e[a])return e[a];s.o(s.S,a)||(s.S[a]={}),s.S[a];var d=[];return e[a]=d.length?Promise.all(d).then((()=>e[a]=1)):1}}})(),s(12744)})();